-- Creaci dels procediments emmagatzemats d'alta, baixa i modificaci de les taules
CREATE OR REPLACE
PROCEDURE Alta_Calendari (pData IN DATE, pDiaSetmana IN VARCHAR2, pFestiu IN CHAR, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Calendari VALUES (pData, pDiaSetmana, pFestiu);
  RSP := 'OK: Dia inserit';
  INSERT INTO LOG_Taula VALUES ('Alta_Calendari', SYSDATE, pData || ',' || pDiaSetmana || ',' || pFestiu, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Alta_Calendari', SYSDATE, pData || ',' || pDiaSetmana || ',' || pFestiu, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Calendari (pData IN DATE, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Calendari WHERE data = pData;
  RSP := 'OK: Dia esborrat';
  INSERT INTO LOG_Taula VALUES ('Baixa_Calendari', SYSDATE, pData, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Calendari', SYSDATE, pData, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Modificar_Calendari (pData IN DATE, pDiaSetmana IN VARCHAR2, pFestiu IN CHAR, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  UPDATE Calendari 
  SET  diaSetmana = pDiaSetmana, 
       Festiu = pFestiu
  WHERE data = pData;
  RSP := 'OK: Dia modificat';
  INSERT INTO LOG_Taula VALUES ('Modificar_Calendari', SYSDATE, pData || ',' || pDiaSetmana || ',' || pFestiu, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Modificar_Calendari', SYSDATE, pData || ',' || pDiaSetmana || ',' || pFestiu, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Assignatura (pNom IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Assignatura(nom) VALUES (pNom);
  RSP := 'OK: Assignatura inserida';
  INSERT INTO LOG_Taula VALUES ('Alta_Assignatura', SYSDATE, pNom, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Alta_Assignatura', SYSDATE, pNom, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Assignatura (pAssignatura IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Assignatura 
  WHERE idAssignatura = pAssignatura;
  RSP := 'OK: Assignatura esborrada';
  INSERT INTO LOG_Taula VALUES ('Baixa_Assignatura', SYSDATE, pAssignatura, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Assignatura', SYSDATE, pAssignatura, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Modificar_Assignatura (pIdAssignatura IN NUMBER, pNom IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  UPDATE Assignatura 
  SET  nom = pNom 
 WHERE idAssignatura = pIdAssignatura;
  RSP := 'OK: Assignatura modificada';
  INSERT INTO LOG_Taula VALUES ('Modificar_Assignatura', SYSDATE, pIdAssignatura || ',' || pNom, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
   INSERT INTO LOG_Taula VALUES ('Modificar_Assignatura', SYSDATE, pIdAssignatura || ',' || pNom, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Curs (pAnyAcademic IN NUMBER, pNom IN VARCHAR2, pTutor IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Curs(anyAcademic, nom, tutor) VALUES (pAnyAcademic, pNom, pTutor);
  RSP := 'OK: Curs inserit';
  INSERT INTO LOG_Taula VALUES ('Alta_Curs', SYSDATE, pAnyAcademic || ',' || pNom || ',' || pTutor, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
   INSERT INTO LOG_Taula VALUES ('Alta_Curs', SYSDATE, pAnyAcademic || ',' || pNom || ',' || pTutor, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Curs (pCurs IN NUMBER, pAnyAcademic IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Curs 
 WHERE idCurs = pCurs AND anyAcademic = pAnyAcademic;
  RSP := 'OK: Curs esborrat';
  INSERT INTO LOG_Taula VALUES ('Baixa_Curs', SYSDATE, pCurs || ',' || pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Curs', SYSDATE, pCurs || ',' || pAnyAcademic, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Modificar_Curs (pIdCurs IN NUMBER, pAnyAcademic IN NUMBER, pNom IN VARCHAR2, pTutor IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  UPDATE Curs
  SET  nom = pNom, 
       tutor = pTutor
  WHERE idCurs = pIdCurs AND anyAcademic = pAnyAcademic;
  RSP := 'OK: Curs modificat';
  INSERT INTO LOG_Taula VALUES ('Modificar_Curs', SYSDATE, pIdCurs || ',' || pAnyAcademic || ',' || pNom || ',' || pTutor, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Modificar_Curs', SYSDATE, pIdCurs || ',' || pAnyAcademic || ',' || pNom || ',' || pTutor, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Assignatures_Curs (pCurs IN NUMBER, pAnyAcademic IN NUMBER, pAssignatura IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Assignatures_Curs VALUES (pCurs, pAnyAcademic, pAssignatura);
  RSP := 'OK: Associaci curs-assignatura inserida';
  INSERT INTO LOG_Taula VALUES ('Alta_Assignatures_Curs', SYSDATE, pCurs|| ',' || pAnyAcademic || ',' || pAssignatura, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
   INSERT INTO LOG_Taula VALUES ('Alta_Assignatures_Curs', SYSDATE, pCurs|| ',' || pAnyAcademic || ',' || pAssignatura, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Calendari_Escolar (pData IN DATE, pHoraInici IN CHAR, pHoraFi IN CHAR, pCurs IN NUMBER, pAnyAcademic IN NUMBER, pAssignatura IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Calendari_Escolar VALUES (pData, pHoraInici, pHoraFi, pCurs, pAnyAcademic, pAssignatura);
  RSP := 'OK: Calendari escolar inserit';
  INSERT INTO LOG_Taula VALUES ('Alta_Calendari_Escolar', SYSDATE, pData || ',' || pHoraInici || ',' || pHoraFi || ',' || pCurs || ',' || pAnyAcademic || ',' || pAssignatura, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
  INSERT INTO LOG_Taula VALUES ('Alta_Calendari_Escolar', SYSDATE, pData || ',' || pHoraInici || ',' || pHoraFi || ',' || pCurs || ',' || pAnyAcademic || ',' || pAssignatura, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Calendari_Escolar (pData IN DATE, pHoraInici IN CHAR, pHoraFi IN CHAR, pCurs IN NUMBER, pAnyAcademic IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Calendari_Escolar
  WHERE data = pData AND horaInici = pHoraInici AND horaFi = pHoraFi AND curs = pCurs AND anyAcademic = pAnyAcademic;
  RSP := 'OK: Calendari escolar esborrat';
  INSERT INTO LOG_Taula VALUES ('Baixa_Calendari_Escolar', SYSDATE, pData || ',' || pHoraInici || ',' || pHoraFi || ',' || pCurs || ',' || pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Calendari_Escolar', SYSDATE, pData || ',' || pHoraInici || ',' || pHoraFi || ',' || pCurs || ',' || pAnyAcademic, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Modificar_Calendari_Escolar (pData IN DATE, pHoraInici IN CHAR, pHoraFi IN CHAR, pCurs IN NUMBER, pAnyAcademic IN NUMBER, pAssignatura IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  UPDATE Calendari_Escolar
  SET  assignatura = pAssignatura
  WHERE data = pData AND horaInici = pHoraInici AND horaFi = pHoraFi AND curs = pCurs AND anyAcademic = pAnyAcademic;
  RSP := 'OK: Calendari escolar modificat';
  INSERT INTO LOG_Taula VALUES ('Modificar_Calendari_Escolar', SYSDATE, pData || ',' || pHoraInici || ',' || pHoraFi || ',' || pCurs || ',' || pAnyAcademic || ',' || pAssignatura, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Modificar_Calendari_Escolar', SYSDATE, pData || ',' || pHoraInici || ',' || pHoraFi ||',' || pCurs || ',' || pAnyAcademic || ',' || pAssignatura, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Alumne (pDNI IN VARCHAR2, pExpedient IN VARCHAR2, pNom IN VARCHAR2, pCognom1 IN VARCHAR2, pCognom2 IN VARCHAR2, pDataNaixement IN DATE, pAdrea IN VARCHAR2, pCiutat IN VARCHAR2, pCodiPostal IN NUMBER, pProvincia IN VARCHAR2, pTelefon IN NUMBER, pMobil IN NUMBER, pEmail IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
INSERT INTO Alumne VALUES (pdni, pExpedient, pNom, pCognom1, pCognom2, pDataNaixement, pAdrea, pCiutat, pCodiPostal, pProvincia, pTelefon, pMobil, pEmail);
  RSP := 'OK: Alumne inserit';
  INSERT INTO LOG_Taula VALUES ('Alta_Alumne', SYSDATE, pDNI || ',' || pExpedient || ',' || pNom || ',' || pCognom1 || ',' || pCognom2 || ',' || pDataNaixement || ',' || pAdrea || ',' || pCiutat ||',' || pCodiPostal || ',' || pProvincia || ',' || pTelefon ||',' || pMobil || ',' || pEmail, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
  INSERT INTO LOG_Taula VALUES ('Alta_Alumne', SYSDATE, pDNI || ',' || pExpedient || ',' || pNom || ',' || pCognom1 || ',' || pCognom2 || ',' || pDataNaixement ||',' || pAdrea || ',' || pCiutat || ',' || pCodiPostal || ',' || pProvincia || ',' || pTelefon ||',' || pMobil || ',' || pEmail, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Alumne (pAlumne IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Alumne
  WHERE DNI = pAlumne;
  RSP := 'OK: Alumne esborrat';
  INSERT INTO LOG_Taula VALUES ('Baixa_Alumne', SYSDATE, pAlumne, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Alumne', SYSDATE, pAlumne, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Modificar_Alumne (pDNI IN VARCHAR2, pExpedient IN VARCHAR2, pNom IN VARCHAR2, pCognom1 IN VARCHAR2, pCognom2 IN VARCHAR2, pDataNaixement IN DATE, pAdrea IN VARCHAR2, pCiutat IN VARCHAR2, pCodiPostal IN NUMBER, pProvincia IN VARCHAR2, pTelefon IN NUMBER, pMobil IN NUMBER, pEmail IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  UPDATE Alumne
  SET  expedient = pExpedient,
       nom = pNom, 
       cognom1 = pCognom1, 
       cognom2 = pCognom2, 
       dataNaixement = pDataNaixement, 
       adrea = pAdrea, 
       ciutat = pCiutat, 
       codiPostal = pCodiPostal, 
       provincia = pProvincia, 
       telefon = pTelefon, 
       mobil = pMobil, 
       email = pEmail
  WHERE DNI = pDNI;
  RSP := 'OK: Alumne modificat';
  INSERT INTO LOG_Taula VALUES ('Modificar_Alumne', SYSDATE, pDNI || ',' || pExpedient || ',' || pNom || ',' || pCognom1 || ',' || pCognom2 || ',' || pDataNaixement || ',' || pAdrea || ',' || pCiutat || ',' || pCodiPostal || ',' || pProvincia || ',' || pTelefon || ',' || pMobil || ',' || pEmail, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Modificar_Alumne', SYSDATE, pDNI || ',' || pExpedient || ',' || pNom || ',' || pCognom1 || ',' || pCognom2 || ',' || pDataNaixement  || ',' || pAdrea || ',' || pCiutat || ',' || pCodiPostal || ',' || pProvincia || ',' || pTelefon || ',' || pMobil || ',' || pEmail, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Matricula (pAlumne IN VARCHAR2, pCurs IN NUMBER, pAnyAcademic IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Matricula VALUES (pAlumne, pCurs, pAnyAcademic);
  RSP := 'OK: Matrcula inserida';
  INSERT INTO LOG_Taula VALUES ('Alta_Matricula', SYSDATE, pAlumne || ',' || pCurs || ',' || pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
  INSERT INTO LOG_Taula VALUES ('Alta_Matricula', SYSDATE, pAlumne || ',' || pCurs || ',' || pAnyAcademic, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Matricula (pAlumne IN VARCHAR2, pCurs IN NUMBER, pAnyAcademic IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Matricula
  WHERE alumne = pAlumne AND curs = pCurs AND anyAcademic = pAnyAcademic;
  RSP := 'OK: Matricula esborrada';
  INSERT INTO LOG_Taula VALUES ('Baixa_Matricula', SYSDATE, pAlumne || ',' || pCurs || ',' || pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Matricula', SYSDATE, pAlumne || ',' || pCurs || ',' || pAnyAcademic, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Professor (pDNI IN VARCHAR2, pNom IN VARCHAR2, pCognom1 IN VARCHAR2, pCognom2 IN VARCHAR2, pDataNaixement IN DATE, pAdrea IN VARCHAR2, pCiutat IN VARCHAR2, pCodiPostal IN NUMBER, pProvincia IN VARCHAR2, pTelefon IN NUMBER, pMobil IN NUMBER, pEmail IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Professor VALUES (pdni, pNom, pCognom1, pCognom2, pDataNaixement, pAdrea, pCiutat, pCodiPostal, pProvincia, pTelefon, pMobil, pEmail);
  RSP := 'OK: Professor inserit';
  INSERT INTO LOG_Taula VALUES ('Alta_Professor', SYSDATE, pDNI || ',' || pNom || ',' || pCognom1 || ',' || pCognom2 || ',' || pDataNaixement || ',' || pAdrea || ',' || pCiutat || ',' || pCodiPostal || ',' || pProvincia || ',' || pTelefon || ',' || pMobil || ',' || pEmail, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
  INSERT INTO LOG_Taula VALUES ('Alta_Professor', SYSDATE, pDNI || ',' || pNom || ',' || pCognom1 || ',' || pCognom2 || ',' || pDataNaixement || ',' || pAdrea || ',' || pCiutat || ',' || pCodiPostal || ',' || pProvincia || ',' || pTelefon || ',' || pMobil || ',' || pEmail, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Professor (pProfessor IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Professor
  WHERE DNI = pProfessor;  
  RSP := 'OK: Professor esborrat';
  INSERT INTO LOG_Taula VALUES ('Baixa_Professor', SYSDATE, pProfessor, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Professor', SYSDATE, pProfessor, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Modificar_Professor (pDNI IN VARCHAR2, pNom IN VARCHAR2, pCognom1 IN VARCHAR2, pCognom2 IN VARCHAR2, pDataNaixement IN DATE, pAdrea IN VARCHAR2, pCiutat IN VARCHAR2, pCodiPostal IN NUMBER, pProvincia IN VARCHAR2, pTelefon IN NUMBER, pMobil IN NUMBER, pEmail IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  UPDATE Professor
  SET  nom = pNom, 
       cognom1 = pCognom1, 
       cognom2 = pCognom2, 
       dataNaixement = pDataNaixement, 
       adrea = pAdrea, 
       ciutat = pCiutat, 
       codiPostal = pCodiPostal, 
       provincia = pProvincia, 
       telefon = pTelefon, 
       mobil = pMobil, 
       email = pEmail
  WHERE DNI = pDNI;  RSP := 'OK: Alumne modificat';
  INSERT INTO LOG_Taula VALUES ('Modificar_Professor', SYSDATE, pDNI || ',' || pNom || ',' || pCognom1 || ',' || pCognom2 || ',' || pDataNaixement || ',' || pAdrea || ',' || pCiutat ',' || pCodiPostal || ',' || pProvincia || ',' || pTelefon || ',' || pMobil || ',' || pEmail, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
  INSERT INTO LOG_Taula VALUES ('Modificar_Professor', SYSDATE, pDNI || ',' || pNom || ',' || pCognom1 || ',' || pCognom2 || ',' || pDataNaixement || ',' || pAdrea || ',' || pCiutat ',' || pCodiPostal || ',' || pProvincia || ',' || pTelefon || ',' || pMobil || ',' || pEmail, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Impartir (pProfessor IN VARCHAR2, pAssignatura IN NUMBER, pCurs IN NUMBER, pAnyAcademic IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Impartir VALUES (pProfessor, pAssignatura, pCurs, pAnyAcademic);
  RSP := 'OK: Associaci professor-assignatura inserida';
  INSERT INTO LOG_Taula VALUES ('Alta_Impartir', SYSDATE, pProfessor || ',' || pAssignatura || ',' || pCurs || ',' || pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
  INSERT INTO LOG_Taula VALUES ('Alta_Impartir', SYSDATE, pProfessor || ',' || pAssignatura || ',' || pCurs || ',' || pAnyAcademic, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Impartir (pProfessor IN VARCHAR2, pAssignatura IN NUMBER, pCurs IN NUMBER, pAnyAcademic IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Impartir
  WHERE professor = pProfessor AND assignatura = pAssignatura AND Curs = pCurs AND anyAcademic = pAnyAcademic;
  RSP := 'OK: Associaci professor-assignatura esborrada';
  INSERT INTO LOG_Taula VALUES ('Baixa_Impartir', SYSDATE, pProfessor || ',' || pAssignatura || ',' || pCurs || ',' || pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Impartir', SYSDATE, pProfessor || ',' || pAssignatura || ',' || pCurs || ',' || pAnyAcademic, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Calendari_Tutoria (pData IN DATE, pHoraInici IN CHAR, pHoraFi IN CHAR, pCurs IN NUMBER, pAnyAcademic IN NUMBER, pTutor IN VARCHAR2, pHorariAlumnes IN CHAR, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Calendari_Tutoria VALUES (pData, pHoraInici, pHoraFi, pCurs, pAnyAcademic, pTutor, pHorariAlumnes);
  RSP := 'OK: Calendari tutoria inserit';
  INSERT INTO LOG_Taula VALUES ('Alta_Calendari_Tutoria', SYSDATE, pData || ',' || pHoraInici || ',' || pHoraFi || ',' || pCurs || ',' || pAnyAcademic || ',' || pTutor || ',' || pHorariAlumnes, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
  INSERT INTO LOG_Taula VALUES ('Alta_Calendari_Tutoria', SYSDATE, pData || ',' || pHoraInici || ',' || pHoraFi || ',' || pCurs || ',' || pAnyAcademic || ',' || pTutor || ',' || pHorariAlumnes, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Calendari_Tutoria (pData IN DATE, pHoraInici IN CHAR, pHoraFi IN CHAR, pCurs IN NUMBER, pAnyAcademic IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Calendari_Tutoria
  WHERE data = pData AND horaInici = pHoraInici AND horaFi = pHoraFi AND curs = pCurs AND anyAcademic = pAnyAcademic;
  RSP := 'OK: Calendari tutoria esborrat';
  INSERT INTO LOG_Taula VALUES ('Baixa_Calendari_Tutoria', SYSDATE, pData || ',' || pHoraInici || ',' || pHoraFi || ',' || pCurs || ',' || pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Calendari_Tutoria', SYSDATE, pData || ',' || pHoraInici  || ',' || pHoraFi || ',' || pCurs || ',' || pAnyAcademic, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Modificar_Calendari_Tutoria (pData IN DATE, pHoraInici IN CHAR, pHoraFi IN CHAR, pCurs IN NUMBER, pAnyAcademic IN NUMBER, pTutor IN VARCHAR2, pHorariAlumnes IN CHAR, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  UPDATE Calendari_Tutoria 
  SET tutor = pTutor,
      horariAlumnes = pHorariAlumnes
  WHERE data = pData AND horaInici = pHoraInici AND horaFi = pHoraFi AND curs = pCurs AND anyAcademic = pAnyAcademic;
    RSP := 'OK: Calendari tutoria modificat';
  INSERT INTO LOG_Taula VALUES ('Modificar_Calendari_Tutoria', SYSDATE, pData || ',' || pHoraInici || ',' || pHoraFi || ',' || pCurs || ',' || pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
  INSERT INTO LOG_Taula VALUES ('Modificar_Calendari_Tutoria', SYSDATE, pData || ',' || pHoraInici || ',' || pHoraFi || ',' || pCurs || ',' || pAnyAcademic, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Reunio_Alumne (pAlumne IN VARCHAR2, pProfessor IN VARCHAR2, pDataiHora IN DATE, pTema IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Reunio_Alumne VALUES (pAlumne, pProfessor, pDataiHora, pTema);
  RSP := 'OK: Reunio amb l''alumne inserida';
  INSERT INTO LOG_Taula VALUES ('Alta_Reunio_Alumne', SYSDATE, pAlumne || ',' || pProfessor || ',' || pDataiHora || ',' || pTema, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Alta_Reunio_Alumne', SYSDATE, pAlumne || ',' || pProfessor || ',' || pDataiHora || ',' || pTema, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Reunio_Alumne (pAlumne IN VARCHAR2, pProfessor IN VARCHAR2, pDataiHora IN DATE, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Reunio_Alumne
  WHERE alumne = pAlumne AND professor = pProfessor AND dataiHora = pDataihora;
  RSP := 'OK: Reuni amb l''alumne esborrada';
  INSERT INTO LOG_Taula VALUES ('Baixa_Reunio_Alumne', SYSDATE, pAlumne || ',' || pProfessor || ',' || pDataiHora, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Reunio_Alumne', SYSDATE, pAlumne || ',' || pProfessor || ',' || pDataiHora, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Modificar_Reunio_Alumne (pAlumne IN VARCHAR2, pProfessor IN VARCHAR2, pDataiHora IN DATE, pTema IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  UPDATE Reunio_Alumne
  SET  tema = pTema 
  WHERE alumne = pAlumne AND professor = pProfessor AND dataiHora = pDataiHora;
  RSP := 'OK: Reuni amb l''alumne modificada';
  INSERT INTO LOG_Taula VALUES ('Modificar_Reunio_Alumne', SYSDATE, pAlumne || ',' || pProfessor ||',' || pDataiHora || ',' || pTema, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Modificar_Reunio_Alumne', SYSDATE, pAlumne || ',' || pProfessor || ',' || pDataiHora || ',' || pTema, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Reunio_Pares (pAlumne IN VARCHAR2, pProfessor IN VARCHAR2, pDataiHora IN DATE, pTema IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Reunio_Pares VALUES (pAlumne, pProfessor, pDataiHora, pTema);
  RSP := 'OK: Reunio amb els pares de l''alumne inserida';
  INSERT INTO LOG_Taula VALUES ('Alta_Reunio_Pares', SYSDATE, pAlumne || ',' || pProfessor || ',' || pDataiHora || ',' || pTema, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Alta_Reunio_Pares', SYSDATE, pAlumne || ',' || pProfessor || ',' || pDataiHora || ',' || pTema, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Reunio_Pares (pAlumne IN VARCHAR2, pProfessor IN VARCHAR2, pDataiHora IN DATE, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Reunio_Pares
  WHERE alumne = pAlumne AND professor = pProfessor AND dataiHora = pDataiHora;
  RSP := 'OK: Reuni amb els pares de l''alumne esborrada';
  INSERT INTO LOG_Taula VALUES ('Baixa_Reunio_Pares', SYSDATE, pAlumne || ',' || pProfessor || ',' || pDataiHora, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Reunio_Pares', SYSDATE, pAlumne || ',' || pProfessor || ',' || pDataiHora, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Modificar_Reunio_Pares (pAlumne IN VARCHAR2, pProfessor IN VARCHAR2, pDataiHora IN DATE, pTema IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  UPDATE Reunio_Pares
  SET  tema = pTema 
  WHERE alumne = pAlumne AND professor = pProfessor AND dataiHora = pDataiHora;
  RSP := 'OK: Reuni amb els pares de l''alumne modificat';
  INSERT INTO LOG_Taula VALUES ('Modificar_Reunio_Pares', SYSDATE, pAlumne || ',' || pProfessor || ',' || pDataiHora || ',' || pTema, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Modificar_Reunio_Pares', SYSDATE, pAlumne || ',' || pProfessor || ',' || pDataiHora || ',' || pTema, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Tipus_Amonestacio (pTipus IN VARCHAR2, pDescripcio IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Tipus_Amonestacio(tipus, descripcio) VALUES (pTipus, pDescripcio);
  RSP := 'OK: Tipus d''amonestaci inserit';
  INSERT INTO LOG_Taula VALUES ('Alta_Tipus_Amonestacio', SYSDATE, pTipus || ',' || pDescripcio, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Alta_Tipus_Amonestacio', SYSDATE, pTipus || ',' || pDescripcio, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Tipus_Amonestacio (pTipus IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Tipus_Amonestacio
  WHERE idTipus = pTipus;
  RSP := 'OK: Tipus d''amonestaci esborrat';
  INSERT INTO LOG_Taula VALUES ('Baixa_Tipus_Amonestacio', SYSDATE, pTipus, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Tipus_Amonestacio', SYSDATE, pTipus, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Modificar_Tipus_Amonestacio (pIdTipus IN NUMBER, pTipus IN VARCHAR2, pDescripcio IN VARCHAR2, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  UPDATE Tipus_Amonestacio
  SET  tipus = pTipus,
      Descripcio = pDescripcio
  WHERE idTipus = pIdTipus;
  RSP := 'OK: Tipus d''amonestaci modificat';
  INSERT INTO LOG_Taula VALUES ('Modificar_Tipus_Amonestaci', SYSDATE, pIdTipus || ',' || pTipus || ',' || pDescripcio, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Modificar_Tipus_Amonestaci', SYSDATE, pIdTipus || ',' || pTipus || ',' || pDescripcio, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Tipus_Sancio (pTipus IN VARCHAR2, pActivacio IN VARCHAR2, pTipusAmonestacio IN NUMBER, pValor IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Tipus_Sancio(tipus, activacio, tipusAmonestacio, valor) VALUES (pTipus, pActivacio, pTipusamonestacio, pValor);
  RSP := 'OK: Tipus de sanci inserit';
  INSERT INTO LOG_Taula VALUES ('Alta_Tipus_Sancio', SYSDATE, pTipus || ',' || pActivacio || ',' || pTipusAmonestacio || ',' || pValor , RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Alta_Tipus_Sancio', SYSDATE, pTipus || ',' || pActivacio || ',' || pTipusAmonestacio || ',' || pValor , RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Tipus_Sancio (pTipus IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Tipus_Sancio
  WHERE idTipus = pTipus;  RSP := 'OK: Tipus de sanci esborrat';
  INSERT INTO LOG_Taula VALUES ('Baixa_TipusSancio', SYSDATE, pTipus, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_TipusSancio', SYSDATE, pTipus, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Modificar_Tipus_Sancio (pIdTipus IN NUMBER, pTipus IN VARCHAR2, pActivacio IN VARCHAR2, pTipusAmonestacio IN NUMBER, pValor IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  UPDATE Tipus_Sancio
  SET  tipus = pTipus,
    activacio = pActivacio,
    tipusAmonestacio = pTipusAmonestacio,
    valor = pValor
  WHERE idTipus = pIdTipus;
  RSP := 'OK: Tipus de sanci modificat';
  INSERT INTO LOG_Taula VALUES ('Modificar_Tipus_Sanci', SYSDATE, pIdTipus || ',' || pTipus || ',' || pTipusAmonestacio || ',' || pValor, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
  INSERT INTO LOG_Taula VALUES ('Modificar_Tipus_Sanci', SYSDATE, pIdTipus || ',' || pTipus || ',' || pTipusAmonestacio || ',' || pValor, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Amonestacio (pDataiHora IN DATE, pComunicacioPares IN CHAR, pGravetat IN VARCHAR2, pAmonestat IN VARCHAR2, pAmonestador IN VARCHAR2, pCurs IN NUMBER, pAnyAcademic IN NUMBER, pAssignatura IN NUMBER, pTipusAmonestacio IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Amonestacio(dataiHora, comunicacioPares, gravetat, amonestat, amonestador, curs, anyAcademic, assignatura, tipusAmonestacio)
  VALUES (pDataiHora, pComunicacioPares, pGravetat, pAmonestat, pAmonestador, pCurs, pAnyAcademic, pAssignatura, pTipusAmonestacio);
  RSP := 'OK: Amonestaci inserida';
  INSERT INTO LOG_Taula VALUES ('Alta_Amonestacio', SYSDATE, pDataiHora || ',' || pComunicacioPares || ',' || pGravetat || ',' || pAmonestat || ',' || pAmonestador || ',' || pCurs || ',' || pAnyAcademic || ',' || pAssignatura || ',' || pTipusAmonestacio, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Alta_Amonestacio', SYSDATE, pDataiHora || ',' || pComunicacioPares || ',' || pGravetat || ',' || pAmonestat || ',' || pAmonestador || ',' || pCurs || ',' || pAnyAcademic || ',' || pAssignatura || ',' || pTipusAmonestacio, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Amonestacio (pAmonestacio IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Amonestacio
  WHERE idAmonestacio = pAmonestacio;
  RSP := 'OK: Amonestaci esborrada';
  INSERT INTO LOG_Taula VALUES ('Baixa_Amonestacio', SYSDATE, pAmonestacio, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Amonestacio', SYSDATE, pAmonestacio, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Modificar_Amonestacio (pIdAmonestacio IN NUMBER, pDataiHora IN DATE, pComunicacioPares IN CHAR, pGravetat IN VARCHAR2, pAmonestat IN VARCHAR2, pAmonestador IN VARCHAR2, pCurs IN NUMBER, pAnyAcademic IN NUMBER, pAssignatura IN NUMBER, pTipusAmonestacio IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  UPDATE Amonestacio
  SET  dataiHora = pDataiHora, 
    comunicacioPares = pComunicacioPares, 
    gravetat = pGravetat, 
    amonestat = pAmonestat, 
    amonestador = pAmonestador, 
    curs = pCurs, 
    anyAcademic = pAnyAcademic, 
    assignatura = pAssignatura, 
    tipusAmonestacio = pTipusAmonestacio
  WHERE idAmonestacio = pIdAmonestacio;
  RSP := 'OK: Amonestaci modificada';
  INSERT INTO LOG_Taula VALUES ('Modificar_Amonestaci', SYSDATE, pIdAmonestacio || ',' || pDataiHora || ',' || pComunicacioPares || ',' || pGravetat || ',' || pAmonestat || ',' || pAmonestador || ',' || pCurs || ',' || pAnyAcademic || ',' || pAssignatura || ',' || pTipusAmonestacio, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Modificar_Amonestaci', SYSDATE, pIdAmonestacio || ',' || pDataiHora || ',' || pComunicacioPares || ',' || pGravetat || ',' || pAmonestat || ',' || pAmonestador || ',' || pCurs || ',' || pAnyAcademic || ',' || pAssignatura || ',' || pTipusAmonestacio, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Alta_Sancio (pData IN DATE, pMotiu IN VARCHAR2, pResolucio IN VARCHAR2, pSancionat IN VARCHAR2, pCurs IN NUMBER, pAnyAcademic IN NUMBER, pTipusSancio IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  INSERT INTO Sancio(data, motiu, resolucio, sancionat, curs, anyAcademic, tipusSancio) VALUES (pData, pMotiu, pResolucio, pSancionat, pCurs, pAnyAcademic, pTipusSancio);
  RSP := 'OK: Sanci inserida';
  INSERT INTO LOG_Taula VALUES ('Alta_Sancio', SYSDATE, pData || ',' || pMotiu || ',' || pResolucio || ',' || pSancionat || ',' || pCurs || ',' || pAnyAcademic || ',' || pTipusSancio, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
  INSERT INTO LOG_Taula VALUES ('Alta_Sancio', SYSDATE, pData || ',' || pMotiu || ',' || pResolucio || ',' || pSancionat || ',' || pCurs || ',' || pAnyAcademic || ',' || pTipusSancio, RSP);
   raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Baixa_Sancio (pSancio IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  DELETE FROM Sancio
  WHERE idSancio = pSancio;  
    RSP := 'OK: Sanci esborrada';
  INSERT INTO LOG_Taula VALUES ('Baixa_Sancio', SYSDATE, pSancio, RSP);
  
      EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Baixa_Sancio', SYSDATE, pSancio, RSP);
   raise past_due;
END;


CREATE OR REPLACE
PROCEDURE Modificar_Sancio (pIdSancio IN NUMBER, pData IN VARCHAR2, pMotiu IN VARCHAR2, pResolucio IN NUMBER, pSancionat IN NUMBER, pCurs IN NUMBER, pAnyAcademic IN NUMBER, pTipusSancio IN NUMBER, RSP OUT VARCHAR2) IS
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
UPDATE Sancio
SET  data = pData, 
    motiu = pMotiu, 
    resolucio = pResolucio, 
    sancionat = pSancionat, 
    curs = pCurs, 
    anyAcademic = pAnyAcademic, 
    tipusSancio = pTipusSancio
  WHERE idSancio = pIdSancio;
  RSP := 'OK: Sanci modificada';
  INSERT INTO LOG_Taula VALUES ('Modificar_Sanci', SYSDATE, pIdSancio || ',' || pData || ',' || pMotiu || ',' || pResolucio || ',' || pSancionat || ',' || pCurs || ',' || pAnyAcademic || ',' || pTipusSancio, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
  INSERT INTO LOG_Taula VALUES ('Modificar_Sanci', SYSDATE, pIdSancio || ',' || pData || ',' || pMotiu || ',' || pResolucio || ',' || pSancionat || ',' || pCurs || ',' || pAnyAcademic || ',' || pTipusSancio, RSP);
   raise past_due;
END;


