-- Creaci dels procediments emmagatzemats de consultes i llistats

-- Consulta del curs d'un alumne entrat com a parmetre
CREATE OR REPLACE 
PROCEDURE Consulta_Curs_Alumne (pAlumne IN VARCHAR2, pAnyAcademic IN NUMBER, RSP OUT VARCHAR2) IS
  c_idCurs NUMBER(5);
  c_nomCurs VARCHAR2(20);
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  SELECT m.curs, c.nom INTO c_idCurs, c_nomCurs
  FROM Matricula m INNER JOIN Curs c ON m.curs = c.idCurs AND m.anyAcademic= c.anyAcademic
  WHERE m.alumne = pAlumne AND m.anyAcademic = pAnyAcademic;
  DBMS_OUTPUT.PUT_LINE('Identificador curs');
  DBMS_OUTPUT.PUT_LINE(c_idCurs);
  DBMS_OUTPUT.PUT_LINE('Nom curs');
  DBMS_OUTPUT.PUT_LINE(c_nomCurs);
  
  RSP := 'OK: Consulta curs alumne';
  INSERT INTO LOG_Taula VALUES ('Consulta_Curs_Alumne', SYSDATE, pAlumne || ',' || pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
   INSERT INTO LOG_Taula VALUES ('Consulta_Curs_Alumne', SYSDATE, pAlumne || ',' || pAnyAcademic, RSP);
   raise past_due;
END;

-- Consulta dels professors que donen una assignatura entrada com a parmetre
CREATE OR REPLACE 
PROCEDURE Consulta_Prof_Assig (pAssignatura NUMBER, pAnyAcademic NUMBER, RSP OUT VARCHAR2) IS
  c_DNI VARCHAR2(10);
  c_Nom VARCHAR2(30);
  c_Cognom1 VARCHAR2(40);
  c_Cognom2 VARCHAR2(40);
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
  Cursor assignatures IS
    SELECT p.DNI, p.nom, p.cognom1, p.cognom2
    FROM Professor p INNER JOIN Impartir i ON p.DNI = i.professor
    WHERE i.assignatura = pAssignatura AND i.anyAcademic = pAnyAcademic
    ORDER BY p.DNI;
BEGIN
  OPEN assignatures;
  LOOP
    FETCH assignatures INTO c_DNI, c_Nom, c_Cognom1, c_Cognom2;
    EXIT WHEN assignatures%NOTFOUND OR assignatures%NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('DNI');
    DBMS_OUTPUT.PUT_LINE(c_DNI);
    DBMS_OUTPUT.PUT_LINE('Nom');
    DBMS_OUTPUT.PUT_LINE(c_Nom);
    DBMS_OUTPUT.PUT_LINE(c_Cognom1);
    DBMS_OUTPUT.PUT_LINE(c_Cognom2);
  END LOOP;
  
  RSP := 'OK: Consulta professors assignatura';
  INSERT INTO LOG_Taula VALUES ('Consulta_Prof_Assig', SYSDATE, pAssignatura || ',' || pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Consulta_Prof_Assig', SYSDATE, pAssignatura || ',' || pAnyAcademic, RSP);
    raise past_due;
END;

-- Consulta de qui s el tutor d'un curs entrat com a parmetre
CREATE OR REPLACE 
PROCEDURE Consulta_Tutor_Curs (pCurs NUMBER, pAnyAcademic NUMBER, RSP OUT VARCHAR2) IS
  c_DNI VARCHAR2(10);
  c_Nom VARCHAR2(30);
  c_Cognom1 VARCHAR2(40);
  c_Cognom2 VARCHAR2(40);
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  SELECT p.DNI, p.nom, p.cognom1, p.cognom2 INTO c_DNI, c_Nom, c_Cognom1, c_Cognom2
  FROM Professor p INNER JOIN Curs c ON p.DNI = c.tutor
  WHERE c.idCurs = pCurs AND c.anyAcademic = pAnyAcademic;
  DBMS_OUTPUT.PUT_LINE('DNI');
  DBMS_OUTPUT.PUT_LINE(c_DNI);
  DBMS_OUTPUT.PUT_LINE('Nom');
  DBMS_OUTPUT.PUT_LINE(c_Nom);
  DBMS_OUTPUT.PUT_LINE(c_Cognom1);
  DBMS_OUTPUT.PUT_LINE(c_Cognom2);
  
  RSP := 'OK: Consulta tutor curs';
  INSERT INTO LOG_Taula VALUES ('Consulta_Tutor_Curs', SYSDATE, pCurs || ',' || pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Consulta_Tutor_Curs', SYSDATE, pCurs || ',' || pAnyAcademic, RSP);
    raise past_due;
END;

-- Consulta de les amonestacions i sancions que t un alumne entrat com a parmetre
CREATE OR REPLACE
PROCEDURE Consulta_AmonSancions_Alumne (pAlumne VARCHAR2, pAnyAcademic NUMBER, RSP OUT VARCHAR2) IS
  c_Id NUMBER(5);
  c_Tipus VARCHAR2(20);
  c_DataiHora DATE;
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
  Cursor amonestacions IS
    SELECT am.tipusAmonestacio, ta.tipus, am.dataiHora
    FROM Alumne al INNER JOIN Amonestacio am ON al.DNI = am.amonestat 
    INNER JOIN Tipus_Amonestacio ta ON am.tipusAmonestacio = ta.idTipus
    WHERE am.amonestat = pAlumne AND am.anyAcademic = pAnyAcademic
    ORDER BY am.dataiHora;
  Cursor sancions IS
    SELECT s.tipusSancio, t.tipus, s.data
    FROM Alumne a INNER JOIN Sancio s ON a.DNI = s.sancionat 
    INNER JOIN Tipus_Sancio t ON s.tipusSancio = t.idTipus
    WHERE s.sancionat = pAlumne AND s.anyAcademic = pAnyAcademic
    ORDER BY s.data;
  BEGIN
  OPEN amonestacions;
  LOOP
    FETCH amonestacions INTO c_Id, c_Tipus, c_DataiHora;
    EXIT WHEN amonestacions%NOTFOUND OR amonestacions%NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('Identificador amonestaci');
    DBMS_OUTPUT.PUT_LINE(c_Id);
    DBMS_OUTPUT.PUT_LINE('Tipus amonestaci');
    DBMS_OUTPUT.PUT_LINE(c_Tipus);
    DBMS_OUTPUT.PUT_LINE('Data i hora amonestaci');
    DBMS_OUTPUT.PUT_LINE(c_DataiHora);
  END LOOP;
  OPEN sancions;
  LOOP
    FETCH sancions INTO c_Id, c_Tipus, c_DataiHora;
    EXIT WHEN sancions%NOTFOUND OR sancions%NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('Identificador sanci');
    DBMS_OUTPUT.PUT_LINE(c_Id);
    DBMS_OUTPUT.PUT_LINE('Tipus sanci');
    DBMS_OUTPUT.PUT_LINE(c_Tipus);
    DBMS_OUTPUT.PUT_LINE('Data sanci');
    DBMS_OUTPUT.PUT_LINE(c_DataiHora);
  END LOOP;
  
  RSP := 'OK: Consulta amonestacions i sancions dels alumnes';
  INSERT INTO LOG_Taula VALUES ('Consulta_AmonSancions_Alumne', SYSDATE, pAlumne || ',' || pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Consulta_AmonSancions_Alumne', SYSDATE, pAlumne || ',' || pAnyAcademic, RSP);
    raise past_due;
END;

-- Llistats amonestacions imposades
CREATE OR REPLACE 
PROCEDURE Llistat_Amonestacions (RSP OUT VARCHAR2) IS
  c_Id NUMBER(5);
  c_Tipus VARCHAR2(20);
  c_DataiHora DATE;
  c_Curs NUMBER(5);
  c_AnyAcademic NUMBER(4);
  c_DNI VARCHAR2(10);
  c_Nom VARCHAR2(30);
  c_Cognom1 VARCHAR2(40);
  c_Cognom2 VARCHAR2(40);
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
  Cursor amonestacions IS
    SELECT am.tipusAmonestacio, ta.tipus, am.dataiHora, am.curs, am.anyAcademic, am.DNI, al.Nom, al.Cognom1, al.Cognom2
    FROM Amonestacio am 
    INNER JOIN Tipus_Amonestacio ta ON am.tipusAmonestacio = ta.idTipus
    INNER JOIN Alumne al ON al.DNI = am.amonestat 
    ORDER BY am.DNI, am.dataiHora;
BEGIN
  OPEN amonestacions;
  LOOP
    FETCH amonestacions INTO c_Id, c_Tipus, c_DataiHora, C_Curs, C_AnyAcademic, C_DNI, C_Nom, c_Cognom1, c_Cognom2;
    EXIT WHEN amonestacions%NOTFOUND OR amonestacions%NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('Identificador amonestaci');
    DBMS_OUTPUT.PUT_LINE(c_Id);
    DBMS_OUTPUT.PUT_LINE(Tipus amonestaci);
    DBMS_OUTPUT.PUT_LINE(c_Tipus);
    DBMS_OUTPUT.PUT_LINE('Data i hora amonestaci');
    DBMS_OUTPUT.PUT_LINE(c_DataiHora);
    DBMS_OUTPUT.PUT_LINE('Curs');
    DBMS_OUTPUT.PUT_LINE(c_Curs);
    DBMS_OUTPUT.PUT_LINE('Any acadmic');
    DBMS_OUTPUT.PUT_LINE(c_AnyAcademic);
    DBMS_OUTPUT.PUT_LINE('DNI');
    DBMS_OUTPUT.PUT_LINE(c_DNI);
    DBMS_OUTPUT.PUT_LINE('Nom');
    DBMS_OUTPUT.PUT_LINE(c_Nom);
    DBMS_OUTPUT.PUT_LINE(c_Cognom1);
    DBMS_OUTPUT.PUT_LINE(c_Cognom2);
  END LOOP;
  
  RSP := 'OK: Llistat amonestacions';
  INSERT INTO LOG_Taula VALUES ('Llistat_Amonestacions', SYSDATE, '', RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Llistat_Amonestacions', SYSDATE, '', RSP);
    raise past_due;
END;

-- Llistat dels alumnes d'un curs entrat com a parmetre
CREATE OR REPLACE 
PROCEDURE Llistat_Alumnes_Curs (pCurs NUMBER, pAnyAcademic NUMBER, RSP OUT VARCHAR2) IS
  c_DNI VARCHAR2(10);
  c_Nom VARCHAR2(30);
  c_Cognom1 VARCHAR2(40);
  c_Cognom2 VARCHAR2(40);
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
  Cursor alumnes IS
    SELECT a.DNI, a.nom, a.cognom1, a.cognom2
  FROM Matricula m INNER JOIN Alumne a ON m.alumne = a.DNI
  WHERE m.curs = pCurs AND m.anyAcademic = pAnyAcademic
  ORDER BY a.DNI;
BEGIN
  OPEN alumnes;
  LOOP
    FETCH alumnes INTO c_DNI, c_Nom, c_Cognom1, c_Cognom2;
    EXIT WHEN alumnes %NOTFOUND OR alumnes %NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('DNI');
    DBMS_OUTPUT.PUT_LINE(c_DNI);
    DBMS_OUTPUT.PUT_LINE('Nom');
    DBMS_OUTPUT.PUT_LINE(c_Nom);
    DBMS_OUTPUT.PUT_LINE(c_Cognom1);
    DBMS_OUTPUT.PUT_LINE(c_Cognom2);
  END LOOP;
  
  RSP := 'OK: Llistat alumnes curs';
  INSERT INTO LOG_Taula VALUES ('Llistat_Alumnes_Curs', SYSDATE, pCurs || ',' || pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Llistat_Alumnes_Curs', SYSDATE, pCurs || ',' || pAnyAcademic, RSP);
    raise past_due;
END;

-- Llistat de les amonestacions i sancions imposades als alumnes
CREATE OR REPLACE 
PROCEDURE Llistat_AmonestacionsSancions (RSP OUT VARCHAR2) IS
  c_Id NUMBER(5);
  c_Tipus VARCHAR2(20);
  C_Descripcio VARCHAR2(50);
  c_Activacio VARCHAR2(50);
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
  Cursor amonestacions IS
    SELECT idTipus, tipus, descripcio
    FROM Tipus_Amonestacio
    ORDER BY idTipus;
  Cursor sancions IS
    SELECT idTipus, tipus, activacio
    FROM Tipus_Sancio
    ORDER BY idTipus;
BEGIN
  OPEN amonestacions;
  LOOP
    FETCH amonestacions INTO c_Id, c_Tipus, c_Descripcio;
    EXIT WHEN amonestacions%NOTFOUND OR amonestacions%NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('Identificador amonestaci');
    DBMS_OUTPUT.PUT_LINE(c_Id);
    DBMS_OUTPUT.PUT_LINE(Tipus amonestaci);
    DBMS_OUTPUT.PUT_LINE(c_Tipus);
    DBMS_OUTPUT.PUT_LINE(Descripci amonestaci);
    DBMS_OUTPUT.PUT_LINE(c_Descripcio);
  END LOOP;
  OPEN sancions;
  LOOP
    FETCH sancions INTO c_Id, c_Tipus, c_Activacio;
    EXIT WHEN sancions%NOTFOUND OR sancions%NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('Identificador sanci');
    DBMS_OUTPUT.PUT_LINE(c_Id);
    DBMS_OUTPUT.PUT_LINE('Tipus sanci');
    DBMS_OUTPUT.PUT_LINE(c_Tipus);
    DBMS_OUTPUT.PUT_LINE('Activaci sanci');
    DBMS_OUTPUT.PUT_LINE(c_Activacio);
  END LOOP;
  
  RSP := 'OK: Llistat amonestacions i sancions';
  INSERT INTO LOG_Taula VALUES ('Llistat_AmonestacionsSancions', SYSDATE, '', RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Llistat_AmonestacionsSancions', SYSDATE, '', RSP);
    raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Llistat_AmonestSancions_Alumne (pAlumne VARCHAR2, RSP OUT VARCHAR2) IS
  c_Id NUMBER(5);
  c_Tipus VARCHAR2(20);
  c_DataiHora DATE;
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
  Cursor amonestacions IS
    SELECT am.tipusAmonestacio, ta.tipus, am.dataiHora
    FROM Alumne al INNER JOIN Amonestacio am ON al.DNI = am.amonestat 
    INNER JOIN Tipus_Amonestacio ta ON am.tipusAmonestacio = ta.idTipus
    WHERE am.amonestat = pAlumne
    ORDER BY am.dataiHora;
  Cursor sancions IS
    SELECT s.tipusSancio, t.tipus, s.data
    FROM Alumne a INNER JOIN Sancio s ON a.DNI = s.sancionat 
    INNER JOIN Tipus_Sancio t ON s.tipusSancio = t.idTipus
    WHERE s.sancionat = pAlumne
    ORDER BY s.data;
BEGIN
  OPEN amonestacions;
  LOOP
    FETCH amonestacions INTO c_Id, c_Tipus, c_DataiHora;
    EXIT WHEN amonestacions%NOTFOUND OR amonestacions%NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('Identificador amonestaci');
    DBMS_OUTPUT.PUT_LINE(c_Id);
    DBMS_OUTPUT.PUT_LINE('Tipus amonestaci');
    DBMS_OUTPUT.PUT_LINE(c_Tipus);
    DBMS_OUTPUT.PUT_LINE('Data i hora amonestaci');
    DBMS_OUTPUT.PUT_LINE(c_DataiHora);
  END LOOP;
  OPEN sancions;
  LOOP
    FETCH sancions INTO c_Id, c_Tipus, c_DataiHora;
    EXIT WHEN sancions%NOTFOUND OR sancions%NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('Identificador sanci');
    DBMS_OUTPUT.PUT_LINE(c_Id);
    DBMS_OUTPUT.PUT_LINE('Tipus sanci');
    DBMS_OUTPUT.PUT_LINE(c_Tipus);
    DBMS_OUTPUT.PUT_LINE('Data sanci');
    DBMS_OUTPUT.PUT_LINE(c_DataiHora);
  END LOOP;
  
  RSP := 'OK: Llistat amonestacions i sancions dels alumnes';
  INSERT INTO LOG_Taula VALUES ('Llistat_AmonestSancions_Alumne', SYSDATE, pAlumne, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Llistat_AmonestSancions_Alumne', SYSDATE, pAlumne, RSP);
    raise past_due;
END;

-- Consulta nmero d'amonestacions dels alumnes
CREATE OR REPLACE 
PROCEDURE Consulta_Numero_Amonestacions_Alumne (RSP OUT VARCHAR2) IS
  C_NumAmonestacons NUMBER(3);
  c_DNI VARCHAR2(10);
  c_Nom VARCHAR2(30);
  c_Cognom1 VARCHAR2(40);
  c_Cognom2 VARCHAR2(40);
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
  Cursor amonestacions IS
    SELECT am.DNI, al.nom, al.cognom1, al.cognom2, am.numAmonestacions
    FROM Numero_Amonestacions_Alumne am INNER JOIN Alumne al ON am.DNI = al.DNI
    ORDER BY am.DNI;
BEGIN
  OPEN amonestacions;
  LOOP
    FETCH amonestacions INTO c_DNI, c_Nom, c_Cognom1, c_Cognom2, c_NumAmonestacions;
    EXIT WHEN amonestacions%NOTFOUND OR amonestacions%NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('DNI alumne');
    DBMS_OUTPUT.PUT_LINE(c_DNI);
    DBMS_OUTPUT.PUT_LINE('Nom alumne');
    DBMS_OUTPUT.PUT_LINE(c_Nom);
    DBMS_OUTPUT.PUT_LINE(c_Cognom1);
    DBMS_OUTPUT.PUT_LINE(c_Cognom2);
    DBMS_OUTPUT.PUT_LINE('Nmero amonestacions');
    DBMS_OUTPUT.PUT_LINE(c_NumAmonestacions);
  END LOOP;
  
  RSP := 'OK: Consulta nmero amonestacions per alumne';
  INSERT INTO LOG_Taula VALUES ('Consulta_Numero_Amonestacions_Alumne', SYSDATE, '', RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Consulta_Numero_Amonestacions_Alumne', SYSDATE, '', RSP);
    raise past_due;
END;

-- Consulta de nmero de sancions per alumne i any
CREATE OR REPLACE 
PROCEDURE Consulta_N_Sancions_AlumneAny (RSP OUT VARCHAR2) IS
  c_NumSancions NUMBER(3);
  c_DNI VARCHAR2(10);
  c_Nom VARCHAR2(30);
  c_Cognom1 VARCHAR2(40);
  c_Cognom2 VARCHAR2(40);
  c_AnyAcademic NUMBER(4);
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
  Cursor sancions IS
    SELECT s.DNI, a.nom, a.cognom1, a.cognom2, s.anyAcademic, s.numSancions
    FROM Numero_Sancions_AlumneAny s INNER JOIN Alumne a ON s.DNI = a.DNI
    ORDER BY s.DNI, anyAcademic;
BEGIN
  OPEN sancions;
  LOOP
    FETCH sancions INTO c_DNI, c_Nom, c_Cognom1, c_Cognom2, c_AnyAcademic, c_NumSancions;
    EXIT WHEN sancions %NOTFOUND OR sancions %NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('DNI alumne');
    DBMS_OUTPUT.PUT_LINE(c_DNI);
    DBMS_OUTPUT.PUT_LINE('Nom alumne');
    DBMS_OUTPUT.PUT_LINE(c_Nom);
    DBMS_OUTPUT.PUT_LINE(c_Cognom1);
    DBMS_OUTPUT.PUT_LINE(c_Cognom2);
    DBMS_OUTPUT.PUT_LINE('Any acadmic');
    DBMS_OUTPUT.PUT_LINE(c_AnyAcademic);
    DBMS_OUTPUT.PUT_LINE('Nmero sancions');
    DBMS_OUTPUT.PUT_LINE(c_NumSancions);
  END LOOP;
  
  RSP := 'OK: Consulta nmero sancions per alumne i any';
  INSERT INTO LOG_Taula VALUES ('Consulta_N_Sancions_AlumneAny', SYSDATE, '', RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Consulta_N_Sancions_AlumneAny', SYSDATE, '', RSP);
    raise past_due;
END;

CREATE OR REPLACE
PROCEDURE Consulta_Mitjana_Amon_ProfAny (RSP OUT VARCHAR2) IS
  c_Mitjana NUMBER(3);
  c_DNI VARCHAR2(10);
  c_Nom VARCHAR2(30);
  c_Cognom1 VARCHAR2(40);
  c_Cognom2 VARCHAR2(40);
  c_AnyAcademic NUMBER(4);
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
  Cursor amonestacions IS
    SELECT a.DNI, p.nom, p.cognom1, p.cognom2, a.anyAcademic, a.mitjanaAmonestacions
    FROM Mitjana_Amonestacions_ProfAny a INNER JOIN Professor p ON a.DNI = p.DNI
    ORDER BY a.DNI, a.anyAcademic;
BEGIN
  OPEN amonestacions;
  LOOP
    FETCH amonestacions INTO c_DNI, c_Nom, c_Cognom1, c_Cognom2, c_AnyAcademic, c_Mitjana;
    EXIT WHEN amonestacions%NOTFOUND OR amonestacions%NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('DNI professor');
    DBMS_OUTPUT.PUT_LINE(c_DNI);
    DBMS_OUTPUT.PUT_LINE('Nom professor');
    DBMS_OUTPUT.PUT_LINE(c_Nom);
    DBMS_OUTPUT.PUT_LINE(c_Cognom1);
    DBMS_OUTPUT.PUT_LINE(c_Cognom2);
    DBMS_OUTPUT.PUT_LINE('Any acadmic');
    DBMS_OUTPUT.PUT_LINE(c_AnyAcademic);
    DBMS_OUTPUT.PUT_LINE('Mitjana amonestacions');
    DBMS_OUTPUT.PUT_LINE(c_Mitjana);
  END LOOP;
  
  RSP := 'OK: Consulta mitjana amonestacions per professor i any';
  INSERT INTO LOG_Taula VALUES ('Consulta_Mitjana_Amon_ProfAny', SYSDATE, '', RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Consulta_Mitjana_Amon_ProfAny', SYSDATE, '', RSP);
    raise past_due;
END;

-- Consulta del nmero de sancions per curs i any
CREATE OR REPLACE 
PROCEDURE Consulta_N_Sancions_CursAny (RSP OUT VARCHAR2) IS
  c_NumSancions NUMBER(3);
  c_IdCurs NUMBER(5);
  c_NomCurs VARCHAR2(20);
  c_AnyAcademic NUMBER(4);
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
  Cursor sancions IS
    SELECT s.curs, s.anyAcademic, c.nom, s.numSancions
    FROM Numero_Sancions_CursAny s INNER JOIN Curs c ON s.curs = c.IdCurs AND s.anyAcademic = c.anyAcademic
    ORDER BY curs, anyAcademic;
BEGIN
  OPEN sancions;
  LOOP
    FETCH sancions INTO c_IdCurs, c_AnyAcademic, c_NomCurs, c_NumSancions;
    EXIT WHEN sancions %NOTFOUND OR sancions %NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('Identificador Curs');
    DBMS_OUTPUT.PUT_LINE(c_IdCurs);
    DBMS_OUTPUT.PUT_LINE('Nom curs');
    DBMS_OUTPUT.PUT_LINE(c_NomCurs);
    DBMS_OUTPUT.PUT_LINE('Any acadmic');
    DBMS_OUTPUT.PUT_LINE(c_AnyAcademic);
    DBMS_OUTPUT.PUT_LINE('Nmero sancions');
    DBMS_OUTPUT.PUT_LINE(c_NumSancions);
  END LOOP;
  
  RSP := 'OK: Consulta nmero sancions per curs i any';
  INSERT INTO LOG_Taula VALUES ('Consulta_N_Sancions_CursAny', SYSDATE, '', RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Consulta_N_Sancions_CursAny', SYSDATE, '', RSP);
    raise past_due;
END;

-- Consulta de l'alumne ms sancionat en l'any entrat com a parmetre
CREATE OR REPLACE 
PROCEDURE Consulta_Alum_Mes_Sanc_Any (pAnyAcademic VARCHAR2, RSP OUT VARCHAR2) IS
  c_NumSancions NUMBER(3);
  c_DNI VARCHAR2(10);
  c_Nom VARCHAR2(30);
  c_Cognom1 VARCHAR2(40);
  c_Cognom2 VARCHAR2(40);
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
BEGIN
  SELECT s.DNI, a.nom, a.cognom1, a.cognom2, s.numSancions INTO c_DNI, c_Nom, c_Cognom1, c_Cognom2, c_NumSancions
  FROM Alumne_Mes_Sancionat_Any s INNER JOIN Alumne a ON s.DNI = a.DNI
  WHERE pAnyAcademic = s.anyAcademic;
  DBMS_OUTPUT.PUT_LINE('DNI alumne');
  DBMS_OUTPUT.PUT_LINE(c_DNI);
  DBMS_OUTPUT.PUT_LINE('Nom alumne');
  DBMS_OUTPUT.PUT_LINE(c_Nom);
  DBMS_OUTPUT.PUT_LINE(c_Cognom1);
  DBMS_OUTPUT.PUT_LINE(c_Cognom2);
  DBMS_OUTPUT.PUT_LINE('Nmero sancions');
  DBMS_OUTPUT.PUT_LINE(c_NumSancions);
  
  RSP := 'OK: Consulta alumne ms sancionat en l''any';
  INSERT INTO LOG_Taula VALUES ('Consulta_Alum_Mes_Sanc_Any', SYSDATE, pAnyAcademic, RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Consulta_Alum_Mes_Sanc_Any', SYSDATE, pAnyAcademic, RSP);
    raise past_due;
END;

-- Consulta del professor ms amonestador per curs
CREATE OR REPLACE 
PROCEDURE Consulta_Prof_Mes_Amonest_Curs (RSP OUT VARCHAR2) IS
  c_NumAmonestacions NUMBER(3);
  c_Curs NUMBER(5);
  c_NomCurs VARCHAR2(20);
  c_DNI VARCHAR2(10);
  c_NomProfessor VARCHAR2(30);
  c_Cognom1 VARCHAR2(40);
  c_Cognom2 VARCHAR2(40);
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
  Cursor amonestacions IS
    SELECT am.curs, c.nom, am.DNI, al.nom, al.cognom1, al.cognom2, am.numAmonestacions
    FROM Professor_Mes_Amonestador_Curs am INNER JOIN Alumne al ON am.DNI = a.DNI INNER JOIN Curs c am.curs = c.idCurs 
   ORDER BY am.DNI;
BEGIN
  OPEN amonestacions;
  LOOP
    FETCH amonestacions INTO c_Curs, c_NomCurs, c_DNI, c_Nom, c_Cognom1, c_Cognom2, c_NumAmonestacions;
    EXIT WHEN amonestacions %NOTFOUND OR amonestacions %NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('Identificador curs');
    DBMS_OUTPUT.PUT_LINE(c_Curs);
    DBMS_OUTPUT.PUT_LINE('Nom curs');
    DBMS_OUTPUT.PUT_LINE(c_NomCurs);
    DBMS_OUTPUT.PUT_LINE('DNI alumne');
    DBMS_OUTPUT.PUT_LINE(c_DNI);
    DBMS_OUTPUT.PUT_LINE('Nom alumne');
    DBMS_OUTPUT.PUT_LINE(c_Nom);
    DBMS_OUTPUT.PUT_LINE(c_Cognom1);
    DBMS_OUTPUT.PUT_LINE(c_Cognom2);
    DBMS_OUTPUT.PUT_LINE('Nmero amonestacions');
    DBMS_OUTPUT.PUT_LINE(c_NumAmonestacions);
  END LOOP;
  
  RSP := 'OK: Consulta professor ms amonestador per curs';
  INSERT INTO LOG_Taula VALUES ('Consulta_Prof_Mes_Amonest_Curs', SYSDATE, '', RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Consulta_Prof_Mes_Amonest_Curs', SYSDATE, '', RSP);
    raise past_due;
END;

-- Consulta mitjana de sancions per curs
CREATE OR REPLACE 
PROCEDURE Consulta_Mitjana_Sancions_Curs (RSP OUT VARCHAR2) IS
  c_Mitjana NUMBER(3);
  c_Curs NUMBER(5);
  c_Nom VARCHAR2(20);
  codiError NUMBER;
  missatgeError VARCHAR2(64);
  past_due exception;
  Cursor sancions IS
    SELECT s.curs, c.nom, s.mitjanaSancions
    FROM Mitjana_Sancions_Curs s INNER JOIN Curs c ON s.curs = c.idCurs
    ORDER BY s.curs;
BEGIN
  OPEN sancions;
  LOOP
    FETCH sancions INTO c_Curs, c_Nom, c_Mitjana;
    EXIT WHEN sancions %NOTFOUND OR sancions %NOTFOUND IS NULL;
    DBMS_OUTPUT.PUT_LINE('Identificador curs');
    DBMS_OUTPUT.PUT_LINE(c_Curs);
    DBMS_OUTPUT.PUT_LINE('Nom curs');
    DBMS_OUTPUT.PUT_LINE(c_Nom);
    DBMS_OUTPUT.PUT_LINE('Mitjana sancions');
    DBMS_OUTPUT.PUT_LINE(c_Mitjana);
  END LOOP;
  
  RSP := 'OK: Consulta mitjana sancions per curs';
  INSERT INTO LOG_Taula VALUES ('Consulta_Mitjana_Sancions_Curs', SYSDATE, '', RSP);
  
  EXCEPTION WHEN OTHERS THEN
    codiError := SQLCODE;
    missatgeError := SUBSTR(SQLERRM, 1, 64);
    RSP := 'ERROR: ' || codiError || ': ' || missatgeError;
    INSERT INTO LOG_Taula VALUES ('Consulta_Mitjana_Sancions_Curs', SYSDATE, '', RSP);
    raise past_due;
END;

