--  Creaci de taules
CREATE TABLE Calendari (
  data DATE CONSTRAINT PK_Calendari PRIMARY KEY,
  diaSetmana VARCHAR2(9)
    CONSTRAINT NN_DiaSetmana NOT NULL
    CONSTRAINT CH_DiaSetmana CHECK (LOWER(diaSetmana) IN ('dilluns', 'dimarts', 'dimecres', 'dijous', 'divendres')),
  festiu CHAR(1)
    CONSTRAINT NN_Festiu NOT NULL
    CONSTRAINT CH_Festiu CHECK (LOWER(festiu) IN ('s', 'n'))
);

CREATE TABLE Professor (
  DNI VARCHAR2(10) CONSTRAINT PK_Professor PRIMARY KEY,
  nom VARCHAR2(30) CONSTRAINT NN_NomProfessor NOT NULL,
  cognom1 VARCHAR2(40) CONSTRAINT NN_Cognom1Professor NOT NULL,
  cognom2 VARCHAR2(40) CONSTRAINT NN_Cognom2Professor NOT NULL,
  dataNaixement DATE CONSTRAINT NN_DataNaixementProfessor NOT NULL,
  adrea VARCHAR2(50) CONSTRAINT NN_AdreaProfessor NOT NULL, 
  ciutat VARCHAR2(30) CONSTRAINT NN_CiutatProfessor NOT NULL, 
  codiPostal NUMBER(5) CONSTRAINT NN_CodiPostalProfessor NOT NULL, 
  provincia VARCHAR2(30) CONSTRAINT NN_ProvinciaProfessor NOT NULL, 
  telefon NUMBER(9), 
  mobil NUMBER(9), 
  email VARCHAR2(20)
);

CREATE TABLE Assignatura (
  idAssignatura NUMBER(5) CONSTRAINT PK_Assignatura PRIMARY KEY,
  nom VARCHAR2(20) CONSTRAINT NN_NomAssignatura NOT NULL
);

CREATE TABLE Curs (
  idCurs NUMBER(5),
  anyAcademic NUMBER(4), 
  nom VARCHAR2(20) CONSTRAINT NN_NomCurs NOT NULL,
  tutor,
  CONSTRAINT PK_Curs PRIMARY KEY (IdCurs, anyAcademic),
  CONSTRAINT FK_Curs FOREIGN KEY (tutor) REFERENCES Professor (DNI) ON DELETE SET NULL
);

CREATE TABLE Assignatures_Curs (
  curs,
  anyAcademic,
  assignatura,
  CONSTRAINT PK_Assignatures_Curs PRIMARY KEY (curs, anyAcademic, assignatura),
  CONSTRAINT FK1_Assignatures_Curs FOREIGN KEY (curs, anyAcademic) REFERENCES Curs (idCurs, anyAcademic) ON DELETE CASCADE,
  CONSTRAINT FK2_Assignatures_Curs FOREIGN KEY (assignatura) REFERENCES Assignatura (idAssignatura) 
);

CREATE TABLE Calendari_Escolar (
  data DATE,
  horaInici CHAR(5)
    CONSTRAINT CH_HoraIniciCalEsc CHECK (REGEXP_LIKE (horaInici, '([[:digit:]]{2})\:([[:digit:]]{2})')) ,
  horaFi CHAR(5)
      CONSTRAINT CH_HoraFiCalEsc CHECK (REGEXP_LIKE (horaFi, '([[:digit:]]{2})\:([[:digit:]]{2})')) ,
  curs NUMBER(5),
  anyAcademic NUMBER(4),
  assignatura NUMBER(5) CONSTRAINT NN_Assignatura NOT NULL,
  CONSTRAINT PK_Calendari_Escolar PRIMARY KEY (data, horaInici, horaFi, curs, anyAcademic),
  CONSTRAINT FK1_Calendari_Escolar FOREIGN KEY (data) REFERENCES Calendari (data),
  CONSTRAINT FK2_Calendari_Escolar FOREIGN KEY (curs, anyAcademic, assignatura) REFERENCES Assignatures_Curs (curs, anyAcademic, assignatura) ON DELETE CASCADE,
  CONSTRAINT CH_HoresCalEsc CHECK (horaFi > horaInici)
);

CREATE TABLE Impartir (
  professor VARCHAR2(10),
  assignatura NUMBER(5),
  curs NUMBER(5),
  anyAcademic NUMBER(4),
  CONSTRAINT PK_Impartir PRIMARY KEY (professor, assignatura, curs, anyAcademic),
  CONSTRAINT FK1_Impartir FOREIGN KEY (professor) REFERENCES Professor (DNI),
  CONSTRAINT FK2_Impartir FOREIGN KEY (assignatura, curs, anyAcademic) REFERENCES Assignatures_Curs (assignatura, curs, anyAcademic) ON DELETE CASCADE
);

CREATE TABLE Calendari_Tutoria (
  data DATE,
  horaInici CHAR(5)
    CONSTRAINT CH_HoraIniciCalTut CHECK (REGEXP_LIKE (horaInici, '([[:digit:]]{2})\:([[:digit:]]{2})')) ,
  horaFi CHAR(5)
        CONSTRAINT CH_HoraFiCalTut CHECK (REGEXP_LIKE (horaFi, '([[:digit:]]{2})\:([[:digit:]]{2})')) ,
  curs NUMBER(5),
  anyAcademic NUMBER(4),
  tutor VARCHAR2(10),
  horariAlumnes CHAR(1) 
    CONSTRAINT NN_horariAlumnes NOT NULL
    CONSTRAINT CH_HorariAlumnes CHECK (LOWER(horariAlumnes) IN ('a', 'p')),
  CONSTRAINT PK_Calendari_Tutoria PRIMARY KEY (data, horaInici, horaFi, curs, anyAcademic),
  CONSTRAINT FK1_Calendari_Tutoria FOREIGN KEY (data) REFERENCES Calendari (data),
  CONSTRAINT FK2_Calendari_Tutoria FOREIGN KEY (curs, anyAcademic) REFERENCES Curs (idCurs, anyAcademic),
  CONSTRAINT FK3_Calendari_Tutoria FOREIGN KEY (tutor) REFERENCES Professor (DNI) ON DELETE SET NULL,
  CONSTRAINT CH_HoresCalTut CHECK (horaFi > horaInici)
);

CREATE TABLE Alumne (
  DNI VARCHAR2(10) CONSTRAINT PK_Alumne PRIMARY KEY,
  expedient VARCHAR2(8) CONSTRAINT NN_Expedient NOT NULL,
  nom VARCHAR2(30) CONSTRAINT NN_NomAlumne NOT NULL,
  cognom1 VARCHAR2(40) CONSTRAINT NN_Cognom1Alumne NOT NULL,
  cognom2 VARCHAR2(40) CONSTRAINT NN_Cognom2Alumne NOT NULL,
  dataNaixement DATE CONSTRAINT NN_DataNaixementAlumne NOT NULL,
  adrea VARCHAR2(50) CONSTRAINT NN_AdreaAlumne NOT NULL, 
  ciutat VARCHAR2(30) CONSTRAINT NN_CiutatAlumne NOT NULL, 
  codiPostal NUMBER(5) CONSTRAINT NN_CodiPostalAlumne NOT NULL, 
  provincia VARCHAR2(30) CONSTRAINT NN_ProvinciaAlumne NOT NULL, 
  telefon NUMBER(9), 
  mobil NUMBER(9), 
  email VARCHAR2(20), 
  CONSTRAINT UN_Alumne UNIQUE (expedient)
);

CREATE TABLE Matricula (
  alumne VARCHAR2(10),
  curs NUMBER(5),
  anyAcademic NUMBER(4),
  CONSTRAINT PK_Matricula PRIMARY KEY (alumne, curs, anyAcademic),
  CONSTRAINT FK1_Matricula FOREIGN KEY (alumne) REFERENCES Alumne (DNI),
  CONSTRAINT FK2_Matricula FOREIGN KEY (curs, anyAcademic) REFERENCES Curs (idCurs, anyAcademic) ON DELETE CASCADE
);

CREATE TABLE Reunio_Alumne (
  alumne VARCHAR2(10),
  professor VARCHAR2(10),
  dataiHora DATE,
  tema VARCHAR2(50),
  CONSTRAINT PK_Reunio_Alumne PRIMARY KEY (alumne, professor, dataiHora),
  CONSTRAINT FK1_Reunio_Alumne FOREIGN KEY (alumne) REFERENCES Alumne (DNI),
  CONSTRAINT FK2_Reunio_Alumne FOREIGN KEY (professor) REFERENCES Professor (DNI)
);

CREATE TABLE Reunio_Pares (
  alumne VARCHAR2(10),
  professor VARCHAR2(10),
  dataiHora DATE,
  tema VARCHAR2(50),
  CONSTRAINT PK_Reunio_Pares PRIMARY KEY (alumne, professor, dataiHora),
  CONSTRAINT FK1_Reunio_Pares FOREIGN KEY (alumne) REFERENCES Alumne (DNI),
  CONSTRAINT FK2_Reunio_Pares FOREIGN KEY (professor) REFERENCES Professor (DNI)
);

CREATE TABLE Tipus_Amonestacio (
  idTipus NUMBER(5) CONSTRAINT PK_Tipus_Amonestacio PRIMARY KEY,
  tipus VARCHAR2(30) CONSTRAINT NN_TipusAmonestacio NOT NULL,
  descripcio VARCHAR2(50) CONSTRAINT NN_Descripcio NOT NULL,
  CONSTRAINT UN_Tipus_Amonestacio UNIQUE (tipus)
);

CREATE TABLE Tipus_Sancio (
  idTipus NUMBER(5) CONSTRAINT PK_Tipus_Sancio PRIMARY KEY,
  tipus VARCHAR2(60) CONSTRAINT NN_TipusSancio NOT NULL,
  activacio VARCHAR2(60) CONSTRAINT NN_Activacio NOT NULL,
  tipusAmonestacio NUMBER(5) CONSTRAINT NN_TipAmonestacio NOT NULL,
  valor NUMBER(2) CONSTRAINT NN_Valor NOT NULL,
  CONSTRAINT FK_Tipus_Sancio FOREIGN KEY (tipusAmonestacio) REFERENCES Tipus_Amonestacio (idTipus),
  CONSTRAINT UN_Tipus_Sancio UNIQUE (tipus)
);

CREATE TABLE Amonestacio (
  idAmonestacio NUMBER(5) CONSTRAINT PK_Amonestacio PRIMARY KEY,
  dataiHora DATE CONSTRAINT NN_DataiHora NOT NULL,
  comunicacioPares CHAR(1)
    CONSTRAINT NN_ComunicacioPares NOT NULL
    CONSTRAINT CH_ComunicacioPares CHECK (LOWER(comunicacioPares) IN ('s', 'n')),
  gravetat VARCHAR2(10) CONSTRAINT NN_Gravetat NOT NULL,
  amonestat VARCHAR2(10)  CONSTRAINT NN_Amonestat NOT NULL,
  amonestador VARCHAR2(10) CONSTRAINT NN_Amonestador NOT NULL,
  curs NUMBER(5) CONSTRAINT NN_CursAmonestacio NOT NULL,
  anyAcademic NUMBER(4) CONSTRAINT NN_AnyAcademicAmonestacio NOT NULL,
  assignatura NUMBER(5) CONSTRAINT NN_AssignaturaAmonestacio NOT NULL,
  tipusAmonestacio NUMBER(5) CONSTRAINT NN_TAmonestacio NOT NULL,
  CONSTRAINT FK1_Amonestacio FOREIGN KEY (amonestat) REFERENCES Alumne (DNI),
  CONSTRAINT FK2_Amonestacio FOREIGN KEY (amonestador) REFERENCES Professor (DNI),
  CONSTRAINT FK3_Amonestacio FOREIGN KEY (curs, anyAcademic, assignatura) REFERENCES Assignatures_Curs (curs, anyAcademic, assignatura),
   CONSTRAINT FK4_Amonestacio FOREIGN KEY (tipusAmonestacio) REFERENCES Tipus_Amonestacio (idTipus)
);

CREATE TABLE Sancio (
  idSancio NUMBER(5) CONSTRAINT PK_Sancio PRIMARY KEY,
  data DATE CONSTRAINT NN_DataSancio NOT NULL,
  motiu VARCHAR2(50) CONSTRAINT NN_Motiu NOT NULL,
  resolucio VARCHAR2(50) CONSTRAINT NN_Resolucio NOT NULL,
  sancionat VARCHAR2(10)  CONSTRAINT NN_Sancionat NOT NULL,
  curs NUMBER(5) CONSTRAINT NN_CursSancio NOT NULL,
  anyAcademic NUMBER(4) CONSTRAINT NN_AnyAcademicSancio NOT NULL,
  tipusSancio NUMBER(5) CONSTRAINT NN_TipSancio NOT NULL,
  CONSTRAINT FK1_Sancio FOREIGN KEY (sancionat) REFERENCES Alumne (DNI),
  CONSTRAINT FK2_Sancio FOREIGN KEY (curs, anyAcademic) REFERENCES Curs (idCurs, anyAcademic),
  CONSTRAINT FK3_Sancio FOREIGN KEY (tipusSancio) REFERENCES Tipus_Sancio (idTipus)
);

CREATE TABLE Log_Taula (
  procediment VARCHAR2(30),
  dataiHora  DATE CONSTRAINT NN_Data NOT NULL,
  entrada VARCHAR2(512) CONSTRAINT NN_Entrada NOT NULL,
  sortida VARCHAR2(512) CONSTRAINT NN_Sortida NOT NULL,
  CONSTRAINT PK_Log_Taula PRIMARY KEY (procediment, dataiHora)
);

CREATE TABLE Numero_Amonestacions_Alumne (
  DNI VARCHAR2(10) CONSTRAINT PK_Numero_Amonestacions_Alumne PRIMARY KEY,
  numAmonestacions NUMBER(3) CONSTRAINT NN_NumAmonestacionsAlumne NOT NULL
);

CREATE TABLE Numero_Sancions_AlumneAny (
  DNI VARCHAR2(10),
  anyAcademic NUMBER(4),
  numSancions NUMBER(3) CONSTRAINT NN_NumSancions NOT NULL,
  CONSTRAINT PK_Numero_Sancions_AlumneAny PRIMARY KEY (DNI, anyAcademic)
);

CREATE TABLE Mitjana_Amonestacions_ProfAny (
  DNI VARCHAR2(10),
  anyAcademic NUMBER(4),
  MitjanaAmonestacions NUMBER(3) CONSTRAINT NN_MitjanaAmonestacions NOT NULL,
  NumAmonestacions NUMBER(3) CONSTRAINT NN_NumAmonestacionsProfAny NOT NULL,
  CONSTRAINT PK_Mitjana_Amonestany PRIMARY KEY (DNI,  anyAcademic)
);

CREATE TABLE Numero_Sancions_CursAny (
  curs NUMBER(5),
  anyAcademic NUMBER(4),
  numSancions NUMBER(3) CONSTRAINT NN_NumSancionsCursany NOT NULL,
  CONSTRAINT PK_Numero_Sancions_CursAny PRIMARY KEY (curs, anyAcademic)
);

CREATE TABLE Alumne_Mes_Sancionat_Any (
  DNI VARCHAR2(10),
  anyAcademic NUMBER(4),
  numSancions NUMBER(3) CONSTRAINT NN_NumSancionsMesSancionat NOT NULL,
  CONSTRAINT PK_Alumne_Mes_Sancionat_Any PRIMARY KEY (DNI, anyAcademic)
);

CREATE TABLE Professor_Mes_Amonestador_Curs (
  DNI VARCHAR2(10),
  curs NUMBER(5),
  anyAcademic NUMBER(4),
  numAmonestacions NUMBER(3) CONSTRAINT NN_NumAmMesAmonestador NOT NULL,
  CONSTRAINT PK_ProfessorMesAmonestadorCurs PRIMARY KEY (DNI, curs, anyAcademic)
);

CREATE TABLE Mitjana_Sancions_Curs (
  curs NUMBER(5), 
  anyAcademic NUMBER(4),
  MitjanaSancions NUMBER(3) CONSTRAINT NN_MitjanaSancions NOT NULL,
  NumSancions NUMBER(3) CONSTRAINT NN_NumSancionsCurs NOT NULL,
  CONSTRAINT PK_Mitjana_Sancions_Curs PRIMARY KEY (curs, anyAcademic)
);

CREATE TABLE Alumnes_Sense_Amonestacions (
  DNI VARCHAR2(10) CONSTRAINT PK_Alumnes_Sense_Amonestacio PRIMARY KEY
);

COMMIT;